# Registry for NuCypher Mainnet

##### Public API

* [NuCypher Token - 0x4fE83213D56308330EC302a8BD641f1d0113A4Cc](https://etherscan.io/address/0x4fE83213D56308330EC302a8BD641f1d0113A4Cc)
* [WorkLock - 0xe9778e69a961e64d3cdbb34cf6778281d34667c2](https://etherscan.io/address/0xe9778e69a961e64d3cdbb34cf6778281d34667c2)
* [StakingEscrow (Dispatcher) - 0xbbD3C0C794F40c4f993B03F65343aCC6fcfCb2e2](https://etherscan.io/address/0xbbD3C0C794F40c4f993B03F65343aCC6fcfCb2e2)
* [PolicyManager (Dispatcher) - 0x67E4A942c067Ff25cE7705B69C318cA2Dfa54D64](https://etherscan.io/address/0x67E4A942c067Ff25cE7705B69C318cA2Dfa54D64)
* [Adjudicator (Dispatcher) - 0x359924Be0640659F34198e518BF3d40Fb56160BE](https://etherscan.io/address/0x359924Be0640659F34198e518BF3d40Fb56160BE)
